package WebGUI::i18n::Spanish::Account_Inbox;
use utf8;
our $I18N = {
  'All users' => {
    'lastUpdated' => '1252505176',
    'message' => 'Todos los Usuarios'
  },
  'accept button label' => {
    'lastUpdated' => '1252505187',
    'message' => 'Aceptar'
  },
  'already a member' => {
    'lastUpdated' => '1252505216',
    'message' => 'La dirección de correo suministrada ya ha sido registrada en este sitio por el usuario %s.'
  },
  'back label' => {
    'lastUpdated' => '1252505236',
    'message' => 'Regresar a Bandeja de Entrada'
  },
  'blocked error' => {
    'lastUpdated' => '1252505246',
    'message' => 'Este usuario no desea recibir mensajes privados.'
  },
  'canSendMessages' => {
    'lastUpdated' => '1252505940',
    'message' => 'Un condicional que indica si el usuario tiene o no amigos a los cuales enviar mensajes.'
  },
  'cancel label' => {
    'lastUpdated' => '1252505948',
    'message' => 'Cancelar'
  },
  'common account variables' => {
    'lastUpdated' => '1252505969',
    'message' => 'Cuenta común, Plugin Bandeja de Entrada, Variables de Plantilla.'
  },
  'compose message label' => {
    'lastUpdated' => '1252505986',
    'message' => 'Redactar mensaje'
  },
  'currently invited' => {
    'lastUpdated' => '1252506038',
    'message' => 'La dirección de correo suministrada, %s, tiene una invitación abierta a este sitio.'
  },
  'date label' => {
    'lastUpdated' => '1252506050',
    'message' => 'Fecha'
  },
  'dateStamp' => {
    'lastUpdated' => '1252506070',
    'message' => 'Fecha en la cual se envió el mensaje, como época Unix.'
  },
  'dateStamp_formatted' => {
    'lastUpdated' => '1252506094',
    'message' => 'La fecha de envío del mensaje, en el formato de fecha y hora preferido por el usuario.'
  },
  'dateStamp_url' => {
    'lastUpdated' => '1252506122',
    'message' => 'El URL para ordenar la Bandeja de Entrada según la fecha de envío.'
  },
  'delete label' => {
    'lastUpdated' => '1252506132',
    'message' => 'Eliminar'
  },
  'deny button label' => {
    'lastUpdated' => '1252506146',
    'message' => 'Impedir'
  },
  'error label' => {
    'lastUpdated' => '1252506156',
    'message' => 'Error'
  },
  'form_footer' => {
    'lastUpdated' => '1252506176',
    'message' => 'Código HTML para terminar el formulario de presentación de la Bandeja de Entrada.'
  },
  'form_header' => {
    'lastUpdated' => '1252506193',
    'message' => 'Código HTML para iniciar el formulario de presentación de la Bandeja de Entrada.'
  },
  'from' => {
    'lastUpdated' => '1252506219',
    'message' => 'El nombre del usuario que envía este mensaje.'
  },
  'from label' => {
    'lastUpdated' => '1252506225',
    'message' => 'De'
  },
  'from_id' => {
    'lastUpdated' => '1252506244',
    'message' => 'El <strong>userId</strong> del usuario que envió este mensaje.'
  },
  'from_url' => {
    'lastUpdated' => '1252506261',
    'message' => 'El URL hacia el Perfil de Usuario del usuario que envió este mensaje.'
  },
  'has_messages' => {
    'lastUpdated' => '1252506282',
    'message' => 'Un condicional que indica si el usuario tiene mensajes o no.'
  },
  'inbox copy sender hoverHelp' => {
    'lastUpdated' => '1252506372',
    'message' => 'Indica si los usuarios reciben copias de los mensajes que envían a través de la Bandeja de Entrada.'
  },
  'inbox copy sender label' => {
    'lastUpdated' => '1252506401',
    'message' => '¿Enviar copia al remitente?'
  },
  'inbox error message template hoverHelp' => {
    'lastUpdated' => '1252506505',
    'message' => 'Seleccione la plantilla para mostrar errores de la Bandeja de Entrada.'
  },
  'inbox error message template label' => {
    'lastUpdated' => '1252506522',
    'message' => 'Plantilla para Errores en Bandeja de Entrada'
  },
  'inbox layout template hoverHelp' => {
    'lastUpdated' => '1252506595',
    'message' => 'Seleccione una Plantilla para desplegar los diversos plugins de Cuenta de Usuario editables por el usuario actual así como los contenidos del plugin actualmente en uso.'
  },
  'inbox layout template label' => {
    'lastUpdated' => '1252506616',
    'message' => 'Plantilla para Edición'
  },
  'inbox manage invitations template hoverHelp' => {
    'lastUpdated' => '1252506642',
    'message' => 'Seleccione la Plantilla a usar para la gestión de invitaciones.'
  },
  'inbox manage invitations template label' => {
    'lastUpdated' => '1252506657',
    'message' => 'Plantilla para Gestión de Invitaciones'
  },
  'inbox message confirm template hoverHelp' => {
    'lastUpdated' => '1252506681',
    'message' => 'Seleccione la Plantilla para mostrar las confirmaciones de envío de mensajes.'
  },
  'inbox message confirm template label' => {
    'lastUpdated' => '1252506696',
    'message' => 'Plantilla para Confirmación de Envío'
  },
  'inbox notification' => {
    'lastUpdated' => '1252506722',
    'message' => 'Hay un mensaje nuevo en su Bandeja de Entrada.'
  },
  'inbox notification template' => {
    'lastUpdated' => '1252506743',
    'message' => 'Plantilla de Notificación de Entrada'
  },
  'inbox notification template help' => {
    'lastUpdated' => '1252506764',
    'message' => 'Seleccione la Plantilla a utilizar para desplegar notificaciones de nuevos mensajes.'
  },
  'inbox notifications subject' => {
    'lastUpdated' => '1252506815',
    'message' => 'Asunto para Notificaciones por Correo'
  },
  'inbox notifications subject help' => {
    'lastUpdated' => '1252506844',
    'message' => 'El asunto a utilizar en las notificaciones de Bandeja de Entrada enviadas por correo electrónico.'
  },
  'inbox rich editor description' => {
    'lastUpdated' => '1252506862',
    'message' => 'El editor a emplear para escribir mensajes'
  },
  'inbox rich editor label' => {
    'lastUpdated' => '1252506882',
    'message' => 'Editor para Mensajes'
  },
  'inbox send message template hoverHelp' => {
    'lastUpdated' => '1252506899',
    'message' => 'Seleccione la Plantilla a utilizar para enviar mensajes.'
  },
  'inbox send message template label' => {
    'lastUpdated' => '1252506916',
    'message' => 'Plantilla para Envío de Mensajes'
  },
  'inbox sms notification' => {
    'lastUpdated' => '1252506938',
    'message' => 'Hay un mensaje nuevo en su Bandeja de Entrada.'
  },
  'inbox sms notification template' => {
    'lastUpdated' => '1252506954',
    'message' => 'Plantilla para Notificación via SMS'
  },
  'inbox sms notification template help' => {
    'lastUpdated' => '1252506981',
    'message' => 'Seleccione la Plantilla a utilizar para enviar Notificaciones de Bandeja de Entrada vía SMS.'
  },
  'inbox style template hoverHelp' => {
    'lastUpdated' => '1252507008',
    'message' => 'Seleccione una Plantilla de estilo para presentar la Bandeja de Entrada.'
  },
  'inbox style template label' => {
    'lastUpdated' => '1252507034',
    'message' => 'Plantilla de Estilo'
  },
  'inbox view invitation template hoverHelp' => {
    'lastUpdated' => '1252507052',
    'message' => 'Selecciona la Plantilla para mostrar una invitación.'
  },
  'inbox view invitation template label' => {
    'lastUpdated' => '1252507073',
    'message' => 'Plantilla para ver Invitación'
  },
  'inbox view message template hoverHelp' => {
    'lastUpdated' => '1252507098',
    'message' => 'Seleccione la Plantilla utilizada para ver un mensaje en la Bandeja de Entrada.'
  },
  'inbox view message template label' => {
    'lastUpdated' => '1252507108',
    'message' => 'Plantilla para Ver Mensaje'
  },
  'inbox view template hoverHelp' => {
    'lastUpdated' => '1252507125',
    'message' => 'Seleccione la Plantilla para desplegar la Bandeja de Entrada.'
  },
  'inbox view template label' => {
    'lastUpdated' => '1252507138',
    'message' => 'Plantilla para Ver Bandeja de Entrada'
  },
  'inbox_form_delete' => {
    'lastUpdated' => '1252507160',
    'message' => 'Un checkbox que permite al usuario indicar si desea eliminar este mensaje.'
  },
  'invalid email' => {
    'lastUpdated' => '1252507172',
    'message' => 'La dirección de correo %s es inválida.'
  },
  'invitation confirm label' => {
    'lastUpdated' => '1252507189',
    'message' => 'Invitaciones Enviadas'
  },
  'invitation confirm message' => {
    'lastUpdated' => '1252507208',
    'message' => 'Se notificó a los usuarios:'
  },
  'invitation confirm message template hoverHelp' => {
    'lastUpdated' => '1252507240',
    'message' => 'Seleccione la Plantilla a utilizar para mostrar las invitaciones confirmadas.'
  },
  'invitation confirm message template label' => {
    'lastUpdated' => '1252507258',
    'message' => 'Plantilla para Confirmar Invitaciones'
  },
  'invitation count' => {
    'lastUpdated' => '1252507264',
    'message' => 'invitaciones'
  },
  'invitation does not exist' => {
    'lastUpdated' => '1252507279',
    'message' => 'La invitación que intenta ver ya ha sido aprobada o rechazada.'
  },
  'invitation label' => {
    'lastUpdated' => '1252507285',
    'message' => 'Invitación'
  },
  'invitation message' => {
    'lastUpdated' => '1252507296',
    'message' => '%s te ha invitado a unirte a su red de amigos'
  },
  'invitation sent label' => {
    'lastUpdated' => '1252507307',
    'message' => 'Invitación enviada'
  },
  'invitation sent text' => {
    'lastUpdated' => '1252507319',
    'message' => 'Tu invitación ha sido enviada!'
  },
  'invitation_count' => {
    'lastUpdated' => '1252507325',
    'message' => 'El número de invitaciones que este usuario ha recibido.'
  },
  'invitations back label' => {
    'lastUpdated' => '1252507332',
    'message' => 'volver a invitaciones'
  },
  'invitations label' => {
    'lastUpdated' => '1252507339',
    'message' => 'Invitaciones'
  },
  'invitations_enabled' => {
    'lastUpdated' => '1252507367',
    'message' => 'Un condicional que indica si el usuario está dispuesto o no a recibir invitaciones para participar en redes de amigos en este sitio.'
  },
  'invite a friend' => {
    'lastUpdated' => '1252507380',
    'message' => 'invitar un amigo a unirse a este sitio'
  },
  'invite message' => {
    'lastUpdated' => '1252507432',
    'message' => 'Soy miembro de un sitio que pienso puede resultarte muy útil, así que te envío esta invitación con la esperanza de que nos encontremos allí. Sigue el enlace más abajo para registrarte en el sitio.'
  },
  'invite subject' => {
    'lastUpdated' => '1252507455',
    'message' => 'Has sido invitado a %s'
  },
  'invite user confirm template hoverHelp' => {
    'lastUpdated' => '1252507501',
    'message' => 'Selecciona la Plantilla para ver las confimaciones de invitación.'
  },
  'invite user confirm template label' => {
    'lastUpdated' => '1252507563',
    'message' => 'Plantilla para Confirmación de Invitación'
  },
  'invite user enabled template hoverHelp' => {
    'lastUpdated' => '1252507609',
    'message' => 'Permitir a los usuarios el envío de mensajes de correo a sus amigos para invitarles a registrarse en el sitio. Para que esta característica opere correctamente, es necesario permitir el Registro Anónimo.'
  },
  'invite user enabled template label' => {
    'lastUpdated' => '1252507642',
    'message' => '¿Permitir el envío de invitaciones?'
  },
  'invite user message hoverHelp' => {
    'lastUpdated' => '1252507684',
    'message' => 'Escriba el texto a enviar en los mensajes de invitación. Puede incluir Macros WebGUI para que sean procesados.'
  },
  'invite user message label' => {
    'lastUpdated' => '1252507770',
    'message' => 'Mensaje Estándar de Invitación'
  },
  'invite user message template hoverHelp' => {
    'lastUpdated' => '1252507989',
    'message' => 'Seleccione la Plantilla para el mensaje de correo que será enviado como invitación. Esto incluye el texto del mensaje así como el enlace para el registro, además de los encabezados o pies indicados para el mensaje.'
  },
  'invite user message template label' => {
    'lastUpdated' => '1252508008',
    'message' => 'Plantilla para Correo de Invitación'
  },
  'invite user restrict message template hoverHelp' => {
    'lastUpdated' => '1252508075',
    'message' => 'Indica si el usuario solamente puede utilizar el mensaje estándar de invitación.'
  },
  'invite user restrict message template label' => {
    'lastUpdated' => '1252508205',
    'message' => '¿Mensaje estándar es obligatorio?'
  },
  'invite user restrict subject template hoverHelp' => {
    'lastUpdated' => '1252508147',
    'message' => 'Indica si el usuario está obligado a utilizar el asunto estándar para invitiaciones.'
  },
  'invite user restrict subject template label' => {
    'lastUpdated' => '1252508188',
    'message' => '¿Asunto estándar es obligatorio?'
  },
  'invite user subject template hoverHelp' => {
    'lastUpdated' => '1252508263',
    'message' => 'Escriba el texto a utilizar para el asunto estándar en las invitaciones. Puede utilizar Macros WebGUI.'
  },
  'invite user subject template label' => {
    'lastUpdated' => '1252508223',
    'message' => 'Asunto Estándar para Invitación'
  },
  'invite user template hoverHelp' => {
    'lastUpdated' => '1233260695',
    'message' => 'Seleccione la plantilla para ver la pantalla principal de invitación a usuario'
  },
  'invite user template label' => {
    'lastUpdated' => '1252508291',
    'message' => 'Plantilla de Envío de Invitación'
  },
  'invite_friend_url' => {
    'lastUpdated' => '1252508297',
    'message' => 'La URL para invitar a este usuario a unirse a tu Red de Amigos'
  },
  'inviter no longer exists' => {
    'lastUpdated' => '1252508311',
    'message' => 'El usuario que envió esta invitación ya no es miembro del sitio.'
  },
  'isCompleted' => {
    'lastUpdated' => '1252508337',
    'message' => 'Un condicional que indica si la acción por parte del usuario se ha completado o no.'
  },
  'isPending' => {
    'lastUpdated' => '1252508377',
    'message' => 'Un condicional que indica si este mensaje representa o no una acción pendiente por parte del usuario.'
  },
  'isRead' => {
    'lastUpdated' => '1252508391',
    'message' => 'Un condicional que indica si este mensaje a sido leído o no.'
  },
  'isReplied' => {
    'lastUpdated' => '1252508409',
    'message' => 'Un condicional que indica si este mensaje ha sido respondido o no.'
  },
  'mark as read label' => {
    'lastUpdated' => '1252508419',
    'message' => 'Marcar como Leído'
  },
  'mark as unread label' => {
    'lastUpdated' => '1252508439',
    'message' => 'Marcar como No Leído'
  },
  'member since' => {
    'lastUpdated' => '1252508450',
    'message' => 'Miembro desde'
  },
  'message count' => {
    'lastUpdated' => '1252508455',
    'message' => 'mensajes'
  },
  'message does not exist' => {
    'lastUpdated' => '1252508472',
    'message' => 'El mensaje que intenta ver ha sido eliminado.'
  },
  'message sent label' => {
    'lastUpdated' => '1252508481',
    'message' => 'Mensaje enviado'
  },
  'message sent text' => {
    'lastUpdated' => '1252508494',
    'message' => 'Su mensaje ha sido enviado con éxito.'
  },
  'message_id' => {
    'lastUpdated' => '1252508505',
    'message' => 'El identificador único para este mensaje.'
  },
  'message_loop' => {
    'lastUpdated' => '1252508536',
    'message' => 'Un ciclo que contiene todos los mensajes, respetando las opciones de ordenamiento y número de mensajes por página.'
  },
  'message_rpp' => {
    'lastUpdated' => '1252508557',
    'message' => 'Un selector que permite al usuario cambiar el número de mensajes mostrados por página.'
  },
  'message_total' => {
    'lastUpdated' => '1252508686',
    'message' => 'Número total de mensajes que el usuario tiene en su Bandeja de Entrada.'
  },
  'message_url' => {
    'lastUpdated' => '1252508700',
    'message' => 'El URL para ver los contenidos del mensaje.'
  },
  'messages label' => {
    'lastUpdated' => '1232664222',
    'message' => 'Mensajes'
  },
  'missing email' => {
    'lastUpdated' => '1252508727',
    'message' => 'No puede enviar la invitación a menos que suministre una dirección de correo electrónico.'
  },
  'missing message' => {
    'lastUpdated' => '1252508775',
    'message' => 'Tu invitación debe incluir un mensaje.'
  },
  'missing subject' => {
    'lastUpdated' => '1252508784',
    'message' => 'Tu invitación debe incluir un asunto.'
  },
  'new message label' => {
    'lastUpdated' => '1252508795',
    'message' => 'Mensaje Nuevo'
  },
  'new_message_url' => {
    'lastUpdated' => '1252508818',
    'message' => 'El URL para llevar al usuario hacia la pantalla en la cual pueden enviar mensajes a otros usuarios.'
  },
  'next label' => {
    'lastUpdated' => '1252508913',
    'message' => 'Siguiente'
  },
  'no access' => {
    'lastUpdated' => '1252509205',
    'message' => 'No tiene permiso para ver ese mensaje.'
  },
  'no access to invitation' => {
    'lastUpdated' => '1252509194',
    'message' => 'No tiene permiso para ver esa invitación.'
  },
  'no email' => {
    'lastUpdated' => '1252509252',
    'message' => 'No puede enviarse la invitiación porque Ud. no tiene dirección de correo electrónica definida en su Perfil de Usuario.'
  },
  'no friends error' => {
    'lastUpdated' => '1252509414',
    'message' => 'No tienes amigos activos en el sistema. Si quieres enviar mensajes privado a un usuario sin ubicar su Perfil, debes agregarlo como amigo antes de hacerlo.'
  },
  'no friends hover' => {
    'lastUpdated' => '1252509426',
    'message' => 'Debes tener amigos activos en el sistema si deseas enviar mensajes privados sin primero tener que localizar su perfil'
  },
  'no invitations' => {
    'lastUpdated' => '1252509477',
    'message' => 'No tiene invitaciones pendientes.'
  },
  'no messagable friends error' => {
    'lastUpdated' => '1252509448',
    'message' => 'Ninguno de tus amigos desea recibir mensajes privados.'
  },
  'no message error' => {
    'lastUpdated' => '1252509499',
    'message' => 'No escribiste mensaje alguno.'
  },
  'no reply error' => {
    'lastUpdated' => '1252509511',
    'message' => 'No tiene permiso para responder al mensaje.'
  },
  'no self error' => {
    'lastUpdated' => '1252509527',
    'message' => 'No puede enviarse mensajes a si mismo.'
  },
  'no subject error' => {
    'lastUpdated' => '1252509539',
    'message' => 'El mensaje no tiene asunto.'
  },
  'no user error' => {
    'lastUpdated' => '1252509556',
    'message' => 'No indicó el destinatario del mensaje.'
  },
  'previous label' => {
    'lastUpdated' => '1252509562',
    'message' => 'Anterior'
  },
  'received label' => {
    'lastUpdated' => '1232664189',
    'message' => 'Recibido'
  },
  'recipients label' => {
    'lastUpdated' => '1252509577',
    'message' => 'Agregar Destinatarios'
  },
  'remove text' => {
    'lastUpdated' => '1232668251',
    'message' => 'Eliminar'
  },
  'reply label' => {
    'lastUpdated' => '1232558140',
    'message' => 'Responder'
  },
  'reply message label' => {
    'lastUpdated' => '1232665050',
    'message' => 'Responder al mensaje'
  },
  'rpp_url' => {
    'lastUpdated' => '1252509598',
    'message' => 'El URL actual con orden, dirección de orden y filtros de usuario.'
  },
  'send inbox notifications only' => {
    'lastUpdated' => '1252509620',
    'message' => 'Sólo enviar Notificaciones de Bandeja de Entrada'
  },
  'send inbox notifications only help' => {
    'lastUpdated' => '1252509667',
    'message' => '¿Enviar solamente la notificación de mensaje nuevo en lugar del mensaje como tal?'
  },
  'send label' => {
    'lastUpdated' => '1232663946',
    'message' => 'Enviar'
  },
  'send reject notice' => {
    'lastUpdated' => '1276808530',
    'message' => 'Enviar Notificaciones de Rechazo'
  },
  'send reject notice help' => {
    'lastUpdated' => '1276808560',
    'message' => 'Indica si al rechazar una solicitud de Hacerse Amigo, también debe enviarse una notifiación al usuario que está siendo rechazado.'
  },
  'status' => {
    'lastUpdated' => '1252509699',
    'message' => 'El estado del mensaje.'
  },
  'status label' => {
    'lastUpdated' => '1232664021',
    'message' => 'Estado'
  },
  'status_class' => {
    'lastUpdated' => '1252509713',
    'message' => 'El estado del mensaje, sin traducir.'
  },
  'status_url' => {
    'lastUpdated' => '1252509732',
    'message' => 'El URL para ordenar la Bandeja de Entrada según estado de los mensajes.'
  },
  'subject' => {
    'lastUpdated' => '1252509743',
    'message' => 'El asunto del mensaje.'
  },
  'subject label' => {
    'lastUpdated' => '1232664015',
    'message' => 'Asunto'
  },
  'subject_url' => {
    'lastUpdated' => '1252509762',
    'message' => 'El URL para ordenar la Bandeja de Entrada por asunto.'
  },
  'system message error' => {
    'lastUpdated' => '1252509784',
    'message' => 'Este es un mensaje enviado por el sistema al cual no se puede responder.'
  },
  'title' => {
    'lastUpdated' => '1252509795',
    'message' => 'Bandeja de Entrada'
  },
  'to label' => {
    'lastUpdated' => '1232664174',
    'message' => 'Para'
  },
  'unread_message_count' => {
    'lastUpdated' => '1252509807',
    'message' => 'El número de mensajes sin leer en la bandeja de entrada.'
  },
  'update label' => {
    'lastUpdated' => '1232664034',
    'message' => 'Actualizar'
  },
  'userFilter' => {
    'lastUpdated' => '1252509828',
    'message' => 'Un selector para filtrar la lista de mensajes según el remitente.'
  },
  'user_invitations_enabled' => {
    'lastUpdated' => '1252509860',
    'message' => 'Un condicional que indica si este sitio permite el envío de invitaciones a usuarios externos.'
  },
  'view inbox template' => {
    'lastUpdated' => '1252509876',
    'message' => 'Plantilla para Ver Bandeja de Entrada'
  },
  'view my profile' => {
    'lastUpdated' => '1252509887',
    'message' => 'ver mi perfil como lo ven otros'
  },
  'view_inbox_url' => {
    'lastUpdated' => '1232666489',
    'message' => 'URL para ver la pantalla Bandeja de Entrada'
  },
  'view_invitations_url' => {
    'lastUpdated' => '1232664349',
    'message' => 'URL para ver la pantalla Invitaciones.'
  }
}
;

1;
